@@ -641,16 +641,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 34
+#define MYSQL_VERSION_PATCH 36
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.34"
+#define PACKAGE_STRING "MySQL Server 10.1.36"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.34"
-#define VERSION "10.1.34"
+#define PACKAGE_VERSION "10.1.36"
+#define VERSION "10.1.36"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
@@ -666,12 +666,6 @@
 #define WSREP_PROC_INFO 1
 #endif
 
-#ifdef _AIX
-/*
-  AIX includes inttypes.h from sys/types.h
-  Explicitly request format macros before the first inclusion of inttypes.h
-*/
 #define __STDC_FORMAT_MACROS
-#endif
 
 #endif
